Changelog
=========

0.2.0 (2014-10-13)
------------------

* Use ThreadingMixin to serve multiple requests at the same time.
* Accept option blksize.

0.1.1 (2014-09-29)
------------------

* Accept, and ignore extra request options.

0.1.0 (2014-09-08)
------------------

* Initial release.
* Only accept TFTP read requests.
